[go: nahoru, domu]

Update Local Overrides UX Writing and docs url

Drive by fix: Other UX Writings in the Sources panel

Screenshot: https://imgur.com/a/vYzMNry (only one of the many changes)

Bug: 1469388,1469415
Change-Id: Ic881c93c4c1f32640a17f19f27c775be5749ee28
Reviewed-on: https://chromium-review.googlesource.com/c/devtools/devtools-frontend/+/4739575
Reviewed-by: Sofia Emelianova <semel@chromium.org>
Reviewed-by: Simon Zünd <szuend@chromium.org>
Commit-Queue: Jecelyn Yeen <jec@chromium.org>
diff --git a/front_end/panels/sources/SourcesNavigator.ts b/front_end/panels/sources/SourcesNavigator.ts
index d310e67..298da55 100644
--- a/front_end/panels/sources/SourcesNavigator.ts
+++ b/front_end/panels/sources/SourcesNavigator.ts
@@ -44,19 +44,13 @@
 
 const UIStrings = {
   /**
-   *@description Text in Sources Navigator of the Sources panel
+   *@description Text to explain the Workspace feature in the Sources panel. https://goo.gle/devtools-workspace
    */
-  syncChangesInDevtoolsWithThe: 'Sync changes in DevTools with the local filesystem',
+  explainWorkspace: 'Set up workspace to sync edits directly to the sources you develop',
   /**
-   * @description Text for link in the Filesystem Side View in Sources Panel. Workspaces is a
-   * DevTools feature that allows editing local files inside DevTools.
-   * See: https://developer.chrome.com/docs/devtools/workspaces/
+   *@description Text to explain the Local Overrides feature. https://goo.gle/devtools-overrides
    */
-  learnMoreAboutWorkspaces: 'Learn more about Workspaces',
-  /**
-   *@description Text in Sources Navigator of the Sources panel
-   */
-  overridePageAssetsWithFilesFromA: 'Override page assets with files from a local folder',
+  explainLocalOverrides: 'Override network requests and web content locally to mock remote resources',
   /**
    *@description Text that is usually a hyperlink to more documentation
    */
@@ -70,13 +64,13 @@
    */
   selectFolderForOverrides: 'Select folder for overrides',
   /**
    *@description Text in Sources Navigator of the Sources panel
    */
-  contentScriptsServedByExtensions: 'Content scripts served by extensions appear here',
+  explainContentScripts: 'View content scripts served by extensions',
   /**
-   *@description Text in Sources Navigator of the Sources panel
+   *@description Text to explain the Snippets feature in the Sources panel https://goo.gle/devtools-snippets
    */
-  createAndSaveCodeSnippetsFor: 'Create and save code snippets for later reuse',
+  explainSnippets: 'Save the JavaScript code you run often to run it again anytime',
   /**
    *@description Text in Sources Navigator of the Sources panel
    */
@@ -185,10 +179,8 @@
     const placeholder = new UI.EmptyWidget.EmptyWidget('');
     this.setPlaceholder(placeholder);
     placeholder.appendParagraph().appendChild(UI.Fragment.html`
-  <div>${i18nString(UIStrings.syncChangesInDevtoolsWithThe)}</div><br />
-  ${
-        UI.XLink.XLink.create(
-            'https://developer.chrome.com/docs/devtools/workspaces/', i18nString(UIStrings.learnMoreAboutWorkspaces))}
+  <div>${i18nString(UIStrings.explainWorkspace)}</div><br />
+  ${UI.XLink.XLink.create('https://goo.gle/devtools-workspace', i18nString(UIStrings.learnMore))}
   `);
 
     const toolbar = new UI.Toolbar.Toolbar('navigator-toolbar');
@@ -233,10 +225,8 @@
     const placeholder = new UI.EmptyWidget.EmptyWidget('');
     this.setPlaceholder(placeholder);
     placeholder.appendParagraph().appendChild(UI.Fragment.html`
-  <div>${i18nString(UIStrings.overridePageAssetsWithFilesFromA)}</div><br />
-  ${
-        UI.XLink.XLink.create(
-            'https://developers.google.com/web/updates/2018/01/devtools#overrides', i18nString(UIStrings.learnMore))}
+  <div>${i18nString(UIStrings.explainLocalOverrides)}</div><br />
+  ${UI.XLink.XLink.create('https://goo.gle/devtools-overrides', i18nString(UIStrings.learnMore))}
   `);
 
     this.toolbar = new UI.Toolbar.Toolbar('navigator-toolbar');
@@ -330,7 +320,7 @@
     const placeholder = new UI.EmptyWidget.EmptyWidget('');
     this.setPlaceholder(placeholder);
     placeholder.appendParagraph().appendChild(UI.Fragment.html`
-  <div>${i18nString(UIStrings.contentScriptsServedByExtensions)}</div><br />
+  <div>${i18nString(UIStrings.explainContentScripts)}</div><br />
   ${UI.XLink.XLink.create('https://developer.chrome.com/extensions/content_scripts', i18nString(UIStrings.learnMore))}
   `);
   }
@@ -359,10 +349,8 @@
     const placeholder = new UI.EmptyWidget.EmptyWidget('');
     this.setPlaceholder(placeholder);
     placeholder.appendParagraph().appendChild(UI.Fragment.html`
-  <div>${i18nString(UIStrings.createAndSaveCodeSnippetsFor)}</div><br />
-  ${
-        UI.XLink.XLink.create(
-            'https://developer.chrome.com/docs/devtools/javascript/snippets/', i18nString(UIStrings.learnMore))}
+  <div>${i18nString(UIStrings.explainSnippets)}</div><br />
+  ${UI.XLink.XLink.create('https://goo.gle/devtools-snippets', i18nString(UIStrings.learnMore))}
   `);
 
     const toolbar = new UI.Toolbar.Toolbar('navigator-toolbar');
@@ -70,13 +64,13 @@
   selectFolderForOverrides: 'Select folder for overrides',
   /**
-   *@description Text in Sources Navigator of the Sources panel
+   *@description Text to explain the content scripts pane in the Sources panel
    */